/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.target.ui;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.team.internal.target.subscriber.TargetDeploymentProvider;
import org.eclipse.team.internal.ui.synchronize.SyncInfoModelElement;
import org.eclipse.team.target.DeploymentProvider;
import org.eclipse.team.target.TeamTarget;
import org.eclipse.ui.model.WorkbenchLabelProvider;

public class DeploymentProviderLabelProvider extends WorkbenchLabelProvider {
	String providerType;
	
	public DeploymentProviderLabelProvider(String providerType) {
		this.providerType = providerType;
	}
	
	private TargetDeploymentProvider getMappedProvider(IResource resource) {
		DeploymentProvider[] providers = TeamTarget.getDeploymentManager().getMappings(resource, providerType);
		if (providers.length > 0) {
			IContainer root = ((TargetDeploymentProvider)providers[0]).getMappedContainer();
			if (root.equals(resource)) {
				return ((TargetDeploymentProvider)providers[0]);
			}
		}
		return null;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.LabelProvider#getText(java.lang.Object)
	 */
	public String decorateText(String text, Object element) {
		IResource resource = null;
		if (element instanceof SyncInfoModelElement) {
			resource = ((SyncInfoModelElement)element).getResource();

		} else if (element instanceof IResource) {
			resource = ((IResource)element);
		}
		if (resource != null) {
			TargetDeploymentProvider provider = getMappedProvider(resource);
			if (provider != null) {
				return provider.getMappedContainer().getFullPath().makeRelative().toString();
			}
		}
		return text;
	}
}
